@@ -1,11 +1,8 @@
 # Copyright (c) 2016, Matt Layman
 
+import sys
 import tempfile
-try:
-    from unittest.runner import TextTestResult
-except ImportError:
-    # Support Python 2.6.
-    from unittest import _TextTestResult as TextTestResult
+from unittest.runner import TextTestResult
 
 from tap.directive import Directive
 from tap.line import Bail, Plan, Result
@@ -31,3 +28,13 @@ class Factory(object):
     def make_test_result(self):
         stream = tempfile.TemporaryFile(mode='w')
         return TextTestResult(stream, None, 1)
+
+    def make_exc(self):
+        """Make a traceback tuple.
+
+        Doing this intentionally is not straight forward.
+        """
+        try:
+            raise ValueError('boom')
+        except ValueError:
+            return sys.exc_info()
