@@ -11,7 +11,8 @@ class TestLine(unittest.TestCase):
 
     def test_line_requires_category(self):
         line = Line()
-        self.assertRaises(NotImplementedError, lambda: line.category)
+        with self.assertRaises(NotImplementedError):
+            line.category
 
 
 class TestResult(unittest.TestCase):
