@@ -3,7 +3,9 @@
 import os
 import unittest
 
+from tap.i18n import _
 from tap.runner import TAPTestResult
+from tap.tests import TestCase
 from tap.tracker import Tracker
 
 
@@ -16,7 +18,7 @@ class FakeTestCase(unittest.TestCase):
         pass
 
 
-class TestTAPTestResult(unittest.TestCase):
+class TestTAPTestResult(TestCase):
 
     @classmethod
     def _make_one(cls):
@@ -51,31 +53,20 @@ class TestTAPTestResult(unittest.TestCase):
 
     def test_adds_skip(self):
         result = self._make_one()
-        try:
-            result.addSkip(FakeTestCase(), 'a reason')
-            self.assertEqual(
-                len(result.tracker._test_cases['FakeTestCase']), 1)
-        except AttributeError:
-            self.assertTrue(True, 'Python 2.6 does not support skip.')
+        result.addSkip(FakeTestCase(), 'a reason')
+        self.assertEqual(len(result.tracker._test_cases['FakeTestCase']), 1)
 
     def test_adds_expected_failure(self):
+        exc = self.factory.make_exc()
         result = self._make_one()
-        try:
-            result.addExpectedFailure(FakeTestCase(), (None, None, None))
-            line = result.tracker._test_cases['FakeTestCase'][0]
-            self.assertEqual(line.status, 'not ok')
-            self.assertEqual(line.directive, '(expected failure)')
-        except AttributeError:
-            self.assertTrue(
-                True, 'Python 2.6 does not support expected failure.')
+        result.addExpectedFailure(FakeTestCase(), exc)
+        line = result.tracker._test_cases['FakeTestCase'][0]
+        self.assertFalse(line.ok)
+        self.assertEqual(line.directive.text, _('(expected failure)'))
 
     def test_adds_unexpected_success(self):
         result = self._make_one()
-        try:
-            result.addUnexpectedSuccess(FakeTestCase())
-            line = result.tracker._test_cases['FakeTestCase'][0]
-            self.assertEqual(line.status, 'ok')
-            self.assertEqual(line.directive, '(unexpected success)')
-        except AttributeError:
-            self.assertTrue(
-                True, 'Python 2.6 does not support unexpected success.')
+        result.addUnexpectedSuccess(FakeTestCase())
+        line = result.tracker._test_cases['FakeTestCase'][0]
+        self.assertTrue(line.ok)
+        self.assertEqual(line.directive.text, _('(unexpected success)'))
